==> zynaddsubfx_1.4.3.orig.tar.gz: zynaddsubfx-1.4.3/src/DSP/FFTwrapper.h <==
/*
  ZynAddSubFX - a software synthesizer
 
  FFTwrapper.h  -  A wrapper for Fast Fourier Transforms
  Copyright (C) 2002-2003 Nasca Octavian Paul
  Author: Nasca Octavian Paul

  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License 
  as published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License (version 2) for more details.

  You should have received a copy of the GNU General Public License (version 2)
  along with this program; if not, write to the Free Software Foundation,
  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

*/

#ifndef FFT_WRAPPER_H
#define FFT_WRAPPER_H

#include "../globals.h"

#include <fftw.h>

/* If you got error messages about rfftw.h, replace the next include  line with "#include <srfftw.h>"
or with "#include <drfftw.h> (if one doesn't work try the other). It may be necessary to replace
the <fftw.h> with <dfftw.h> or <sfftw.h>. If the neither one doesn't work, 
please install latest version of fftw(recomanded from the sources) from www.fftw.org. 
Hope all goes right." */
#include <rfftw.h>

class FFTwrapper{
    public:
	FFTwrapper(int fftsize_);
	~FFTwrapper();
	void smps2freqs(REALTYPE *smps,REALTYPE *freqs);
	void freqs2smps(REALTYPE *freqs,REALTYPE *smps);
    private:
	int fftsize;
	fftw_real *tmpfftdata1,*tmpfftdata2;
	rfftw_plan planfftw,planfftw_inv;
};
#endif

==> zynaddsubfx_2.2.1.orig.tar.gz: zynaddsubfx-2.2.1/src/DSP/FFTwrapper.h <==
/*
  ZynAddSubFX - a software synthesizer
 
  FFTwrapper.h  -  A wrapper for Fast Fourier Transforms
  Copyright (C) 2002-2005 Nasca Octavian Paul
  Author: Nasca Octavian Paul

  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License 
  as published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License (version 2) for more details.

  You should have received a copy of the GNU General Public License (version 2)
  along with this program; if not, write to the Free Software Foundation,
  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

*/

#ifndef FFT_WRAPPER_H
#define FFT_WRAPPER_H

#include "../globals.h"

#ifdef FFTW_VERSION_2

#include <fftw.h>

/* If you got error messages about rfftw.h, replace the next include  line with "#include <srfftw.h>"
or with "#include <drfftw.h> (if one doesn't work try the other). It may be necessary to replace
the <fftw.h> with <dfftw.h> or <sfftw.h>. If the neither one doesn't work, 
please install latest version of fftw(recomanded from the sources) from www.fftw.org.
If you'll install fftw3 you need to change the Makefile.inc
Hope all goes right." */
#include <rfftw.h>

#else

#include <fftw3.h>
#define fftw_real double
#define rfftw_plan fftw_plan
#endif

class FFTwrapper{
    public:
	FFTwrapper(int fftsize_);
	~FFTwrapper();
	void smps2freqs(REALTYPE *smps,FFTFREQS freqs);
	void freqs2smps(FFTFREQS freqs,REALTYPE *smps);
    private:
	int fftsize;
	fftw_real *tmpfftdata1,*tmpfftdata2;
	rfftw_plan planfftw,planfftw_inv;
};
#endif
